//
// Wood Shader, based on:
// CGII 1.9 Prozedurale Texturen
//

float ringscale = 1.2;
float irregularity = 0.3;

vec4 wood_light = vec4(0.91, 0.76, 0.65, 1.0);
vec4 wood_medium = vec4(0.66, 0.50, 0.39, 1.0);
vec4 wood_dark = vec4(0.52, 0.37, 0.26, 1.0);

vec4 woodColor(vec3 point) {
	float seed = cnoise(point);
	
	point += vec3(irregularity*seed); // add irregularity
	
	// radial distance r between point and tree axis
	float r = sqrt(point.x * point.x + point.y * point.y);
	
	// map radial distance r into ring range [0,1]
	r /= ringscale;
	r += abs(cnoise(vec3(r)));
	r = fract(r);
	
	// soft increase and sharp falloff
	r = smoothstep(0.2, 0.55, r) * (1 - smoothstep(0.75, 0.8, r));
	
	// add some impurity
	float impurity = 0.9 + 0.1*cnoise(vec3(seed));
	
	return vec4(impurity * mix(wood_medium, wood_dark, r).rgb,1.0);
}